netapp_ontap.models.sql_on_san API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.sql_on_san`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SqlOnSanSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SqlOnSan object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `db: SqlOnSanDb GET POST PATCH`

    The db field of the sql_on_san.

  `igroup_name: str GET POST PATCH`

    The name of the initiator group through which the contents of this application will be accessed. Modification of this parameter is a disruptive operation. All LUNs in the application component will be unmapped from the current igroup and re-mapped to the new igroup.

  `log: SqlOnSanLog GET POST PATCH`

    The log field of the sql_on_san.

  `new_igroups: List[SqlOnSanNewIgroups] POST PATCH`

    The list of initiator groups to create.

  `os_type: str GET POST`

    The name of the host OS running the application.

    Valid choices:

    - windows
    - windows_2008
    - windows_gpt
  `protection_type: MongoDbOnSanProtectionType GET POST PATCH`

    The protection_type field of the sql_on_san.

  `server_cores_count: Size GET POST`

    The number of server cores for the DB.

  `temp_db: SqlOnSanTempDb GET POST PATCH`

    The temp_db field of the sql_on_san.